==> ocstore25_6_20.zip: OcStore/Spiky/GameMsgbox.h <==
#pragma once
#include "global.h"
struct MyView;
struct GameInput;
class Entity;
//ǰ
struct CmdTextFormat;
//Ϸı
class GameMsgbox
{
public:
	virtual ~GameMsgbox();
	void Init(MyDX11Renderer* pRenderer, MyView* pView, void* pGameScript, std::weak_ptr<Entity>* mychar_ptr_Player1, std::weak_ptr<Entity>* mychar_ptr_Player2);
	void Step();
	void Draw(float deltaTime);
	void OnResetScale();
	void MSG(const wchar_t* text, int mode);//·ı
	void MS2(const wchar_t* text, int mode);//Ϸı
	void MS3(const wchar_t* text, int mode);//Ϸı
	void AutoMSG(const wchar_t* text, int mode, float entity_y);//Զı
	void MSS(int speed);
	void TUR(bool tur);
	void NOD();
	void CAT(const wchar_t* text, int mode);
	void CLR();
	void CLO();
	void FAC(std::wstring faceID);
	void FNT(const wchar_t* fontFamily);
	void FCL(BYTE r, BYTE g, BYTE b, BYTE a);
	void FSZ();
	void FSZ(int fontSize);
	void STY(const wchar_t* msgboxStyle);
	void EndEvent();
	void YNJ();
	void JNYSetYesNo(bool bYes);
	void YNJEnd();
	const wchar_t* GetMsgBoxStyle();
	void SetSideMode(int sideMode);
private:
	MyDX11Renderer* pRenderer = nullptr;
	MyView* pView = nullptr;
	void* pGameScript = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player1 = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player2 = nullptr;
	bool bShow = false;//ǷʾϢкı
	bool bShowYNJ = true;//Ƿʾѡ
	bool bYesNo = true;//YNJѡĬYes
	//Ϣ
	std::wstring msgbox_now;
	int msgbox_mode = 0;//0· 1Ϸ 2Ϸ
	float msgbox_x = 0, msgbox_y = 0;
	int msgbox_count_w = 24;
	int msgbox_count_h = 5;
	float face_offx = 0;
	//ıʾ
	MyTextureAndSRV textBuffer1;//ʾ
	ID3D11RenderTargetView* pRTV_textBuffer1 = nullptr;
	float text_cursorX1 = 0, text_cursorY1 = 0;//ı
	MyTextureAndSRV textBuffer2;//ʾ
	ID3D11RenderTargetView* pRTV_textBuffer2 = nullptr;
	float text_cursorX2 = 0, text_cursorY2 = 0;//ı
	bool bufferSwitch = false;//лʾ
	bool bufferOutSwitch = false;//лʾ
	int text_interval = 5;//ʾ
	int text_interval_counter = 0;//ʾʱ
	int text_lineheight;//и
	bool text_rolling = false;//ıǷڹ
	int text_rolling_speed = 0;//ıٶ
	int text_rolling_counter = 0;//ıʱ
	float dst_drawbuffer1_y_set = 0;//ı1y
	float dst_drawbuffer1_y_set_last = 0;//ı1y
	float dst_drawbuffer2_y_set = 0;//ı2y
	float dst_drawbuffer2_y_set_last = 0;//ı2y
	bool text_tur = false;
	//
	int text_nod_linecounter = 0;
	int text_nod_counter = 0;
	int text_nod_counter_max = 30;
	//
	std::wstring text_fontFamily_default;
	std::wstring text_fontFamily = text_fontFamily_default;//
	int text_fontSize, text_fontSize_default;//С
	SDL_Color text_color_default;
	SDL_Color text_color;//ɫ
	//ı
	std::wstring msg;//ı
	int msg_index = 0;//ı±
	std::unordered_map<int, CmdTextFormat> msg_format;
	//ͷ
	std::wstring face_id;//ʾID
	float face_counter_set = 0;
	float face_counter_set_last = 0;
	//
	std::vector<char> gbk;
	void DrawFrame();//ı
	void DrawMsgboxText(float deltaTime);//
	void DrawCursor();//ƹ
	void DrawFace(float deltaTime);//ͷ
	void RenderText();
	void ClearText();
	//ı
	void TextSound();
	std::wstring text_soundName = L"MSGNormal";
	bool scaleChanging = false;
	//
	int sideMode = 0;//Ʒıʾģʽı-1ࡢ1ıҲࣩ
	int CalcSpaceNum(const wchar_t* text, int mode);
};
//ıɫ
struct CmdTextFormat
{
	SDL_Color text_color;
	int text_fontSize;
	std::wstring text_fontFamily;
};

==> ocstore25_7_4.zip: OcStore/Spiky/GameMsgbox.h <==
#pragma once
#include "global.h"
struct MyView;
struct GameInput;
class Entity;
//ǰ
struct CmdTextFormat;
//Ϸı
class GameMsgbox
{
public:
	virtual ~GameMsgbox();
	void Init(MyDX11Renderer* pRenderer, MyView* pView, void* pGameScript, std::weak_ptr<Entity>* mychar_ptr_Player1, std::weak_ptr<Entity>* mychar_ptr_Player2);
	void Step();
	void Draw(float deltaTime);
	void OnResetScale();
	void MSG(const wchar_t* text, int mode);//·ı
	void MS2(const wchar_t* text, int mode);//Ϸı
	void MS3(const wchar_t* text, int mode);//Ϸı
	void AutoMSG(const wchar_t* text, int mode, float entity_y);//Զı
	void MSS(int speed);
	void TUR(bool tur);
	void NOD();
	void CAT(const wchar_t* text, int mode);
	void CLR();
	void CLO();
	void FAC(std::wstring faceID);
	void FNT(const wchar_t* fontFamily);
	void FCL(BYTE r, BYTE g, BYTE b, BYTE a);
	void FSZ();
	void FSZ(int fontSize);
	void STY(const wchar_t* msgboxStyle);
	void EndEvent();
	void YNJ();
	void JNYSetYesNo(bool bYes);
	void YNJEnd();
	const wchar_t* GetMsgBoxStyle();
	void SetSideMode(int sideMode);
private:
	MyDX11Renderer* pRenderer = nullptr;
	MyView* pView = nullptr;
	void* pGameScript = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player1 = nullptr;
	std::weak_ptr<Entity>* mychar_ptr_Player2 = nullptr;
	bool bShow = false;//ǷʾϢкı
	bool bShowYNJ = true;//Ƿʾѡ
	bool bYesNo = true;//YNJѡĬYes
	//Ϣ
	std::wstring msgbox_now;
	int msgbox_mode = 0;//0· 1Ϸ 2Ϸ
	float msgbox_x = 0, msgbox_y = 0;
	int msgbox_count_w = 24;
	int msgbox_count_h = 5;
	float face_offx = 0;
	//ıʾ
	MyTextureAndSRV textBuffer1;//ʾ
	ID3D11RenderTargetView* pRTV_textBuffer1 = nullptr;
	float text_cursorX1 = 0, text_cursorY1 = 0;//ı
	MyTextureAndSRV textBuffer2;//ʾ
	ID3D11RenderTargetView* pRTV_textBuffer2 = nullptr;
	float text_cursorX2 = 0, text_cursorY2 = 0;//ı
	bool bufferSwitch = false;//лʾ
	bool bufferOutSwitch = false;//лʾ
	int text_interval = 5;//ʾ
	int text_interval_counter = 0;//ʾʱ
	int text_lineheight;//и
	bool text_rolling = false;//ıǷڹ
	int text_rolling_speed = 0;//ıٶ
	int text_rolling_counter = 0;//ıʱ
	float dst_drawbuffer1_y_set = 0;//ı1y
	float dst_drawbuffer1_y_set_last = 0;//ı1y
	float dst_drawbuffer2_y_set = 0;//ı2y
	float dst_drawbuffer2_y_set_last = 0;//ı2y
	bool text_tur = false;
	bool text_tur_temp = false;
	//
	int text_nod_linecounter = 0;
	int text_nod_counter = 0;
	int text_nod_counter_max = 30;
	//
	std::wstring text_fontFamily_default;
	std::wstring text_fontFamily = text_fontFamily_default;//
	int text_fontSize, text_fontSize_default;//С
	SDL_Color text_color_default;
	SDL_Color text_color;//ɫ
	//ı
	std::wstring msg;//ı
	int msg_index = 0;//ı±
	std::unordered_map<int, CmdTextFormat> msg_format;
	//ͷ
	std::wstring face_id;//ʾID
	float face_counter_set = 0;
	float face_counter_set_last = 0;
	//
	std::vector<char> utf8;
	void DrawFrame();//ı
	void DrawMsgboxText(float deltaTime);//
	void DrawCursor();//ƹ
	void DrawFace(float deltaTime);//ͷ
	void RenderText();
	void ClearText();
	//ı
	void TextSound();
	std::wstring text_soundName = L"MSGNormal";
	bool scaleChanging = false;
	//
	int sideMode = 0;//Ʒıʾģʽı-1ࡢ1ıҲࣩ
	int CalcSpaceNum(const wchar_t* text, int mode);
};
//ıɫ
struct CmdTextFormat
{
	SDL_Color text_color;
	int text_fontSize;
	std::wstring text_fontFamily;
};
